@@ -12,14 +12,14 @@ import (
 
 	tunedv1 "github.com/openshift/cluster-node-tuning-operator/pkg/apis/tuned/v1"
 	ntoconfig "github.com/openshift/cluster-node-tuning-operator/pkg/config"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 )
 
 const (
 	// Assets
-	TunedDaemonSetAsset      = "assets/tuned/ds-tuned.yaml"
-	TunedProfileAsset        = "assets/tuned/tuned-profile.yaml"
-	TunedCustomResourceAsset = "assets/tuned/default-cr-tuned.yaml"
+	TunedDaemonSetAsset      = "assets/tuned/manifests/ds-tuned.yaml"
+	TunedProfileAsset        = "assets/tuned/manifests/tuned-profile.yaml"
+	TunedCustomResourceAsset = "assets/tuned/manifests/default-cr-tuned.yaml"
 )
 
 func MustAssetReader(asset string) io.Reader {
